JitsiMeet class
The entry point for the sdk. It is used to launch the meeting screen, to send and receive all the events.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeChat(
) → Future< MethodResponse> - Closes the chat dialog.
-
createRecordingFolder(
) → Future< MethodResponse> -
deleteRecordingFolder(
) → Future< MethodResponse> -
enterPiP(
) → Future< MethodResponse> - Enters Picture in Picture mode.
-
getPlatformVersion(
) → Future< String?> -
getRecordingFolderPath(
) → Future< String?> -
hangUp(
) → Future< MethodResponse> - The localParticipant leaves the current meeting.
-
join(
[JitsiMeetEventListener? listener]) → void -
Joins a meeting with the given meeting
optionsand optionally alisteneris given for listening to events triggered by the native sdks. -
leave(
) → Future< MethodResponse> -
makeChatGPTRequest(
String bearer, String prompt, {String model = 'gpt-4-turbo', int maxTokens = 4096}) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openChat(
[String? to]) → Future< MethodResponse> -
Opens the chat dialog. If
tocontains a valid participantId, the private chat with that particular participant will be opened. -
retrieveParticipantsInfo(
) → Future< MethodResponse> - Sends and event that will trigger the JitsiMeetEventListener.participantsInfoRetrieved event which will contain participants information.
-
sendChatMessage(
{String? to, required String message}) → Future< MethodResponse> -
Sends a chat message via
toone particular participant or to all of them. If thetoparam is empty, themessagewill be sent to all the participants in the conference. -
sendEndpointTextMessage(
{String? to, required String message}) → Future< MethodResponse> -
Sends a message via the data channel
toone particular participant or to all of them. If thetoparam is empty, themessagewill be sent to all the participants in the conference. -
setAudioMuted(
bool muted) → Future< MethodResponse> -
Sets the state of the localParticipant audio
mutedaccording to the muted parameter. -
setVideoMuted(
bool muted) → Future< MethodResponse> -
Sets the state of the localParticipant video
mutedaccording to the muted parameter. -
startRecording(
) → Future< MethodResponse> -
stopRecording(
) → Future< String?> -
Sets the state of the localParticipant screen sharing according to the
enabledparameter. -
toString(
) → String -
A string representation of this object.
inherited
-
transcribeWithWhisper(
String bearer, String recordingFilePath, String? language, {String model = 'whisper-1'}) → Future< String?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited