JitsiMeetUserInfo class

Information about the local user. It will be used in absence of a token.

Constructors

JitsiMeetUserInfo({String? displayName, String? email, String? avatar})

Properties

avatar String?
URL for the user avatar.
getter/setter pair
displayName String?
User display name.
getter/setter pair
email String?
User email.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited